Crate async_callback_manager

Crate async_callback_manager 

Modules

task_list

Structs

AsyncCallbackManager
AsyncTask
An asynchrnonous task that can generate state mutations and/or more tasks to be spawned by an AsyncCallbackManager.
Constraint
Map
NoOpHandler
PanickingReceiverStream
A modification to tokio’s ReceiverStream that awaits a JoinHandle prior to reporting closed, rethrowing the panic if there was one. Use this when the ReceiverStream is driven by a task that may panic.
TaskId
TaskInformation
User visible struct for introspection.
Then

Enums

ConstraitType
Error
TaskOutcome

Traits

BackendStreamingTask
A task of kind T that can be run on a backend, returning a stream of outputs Output. The type must implement Any, as the TypeId is used as part of the task management process.
BackendTask
A task of kind T that can be run on a backend, returning a future of output Output. The type must implement Any, as the TypeId is used as part of the task management process.
BackendTaskExt
FrontendEffect
Represents a mutation that can be applied to some state, returning an effect.
MapFn
Local definition of the unstable FnOnce trait, allowing users of this crate to implement mapping functions that are PartialEq and Debug for observability purposes.
OptDebug
OptPartialEq
TaskHandler
Represents the handler for a task output.
TryBackendTaskExt

Type Aliases

Result