Crate async_callback_manager

Crate async_callback_manager 

Structs

AsyncCallbackManager
AsyncTask
An asynchrnonous task that can generate state mutations and/or more tasks to be spawned by an AsyncCallbackManager.
Constraint
Map
PanickingReceiverStream
A modification to tokio’s ReceiverStream that awaits a JoinHandle prior to reporting closed, rethrowing the panic if there was one. Use this when the ReceiverStream is driven by a task that may panic.
TaskId
TaskInformation
User visible struct for introspection.
Then

Enums

Error
TaskOutcome

Traits

BackendStreamingTask
A task of kind T that can be run on a backend, returning a stream of outputs Output. The type must implement Any, as the TypeId is used as part of the task management process.
BackendTask
A task of kind T that can be run on a backend, returning a future of output Output. The type must implement Any, as the TypeId is used as part of the task management process.
BackendTaskExt
BkendMap
TryBackendTaskExt

Type Aliases

Result